Class: Showroom::Search::ProductSuggestion
- Inherits:
-
Suggestion
- Object
- Resource
- Suggestion
- Showroom::Search::ProductSuggestion
- Defined in:
- lib/showroom/models/search/product_suggestion.rb
Overview
A lean product shape returned by the Shopify search suggest endpoint.
Instance Attribute Summary
Attributes inherited from Resource
Class Method Summary collapse
-
.complete_model_class ⇒ Class
The full model class for this suggestion type.
Methods inherited from Suggestion
Methods inherited from Resource
#==, #[], has_many, has_one, #initialize, #inspect, main_attr_keys, main_attrs, #method_missing, #respond_to_missing?, #to_h
Constructor Details
This class inherits a constructor from Showroom::Resource
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Showroom::Resource
Class Method Details
.complete_model_class ⇒ Class
Returns the full model class for this suggestion type.
15 16 17 |
# File 'lib/showroom/models/search/product_suggestion.rb', line 15 def self.complete_model_class Product end |